@@ -154,7 +154,8 @@ def _stringify_query():
 
     q = Query(None)
     q_keys = q.__dict__.keys()
-    q_ignored = ['join_map', 'dupe_avoidance', '_extra_select_cache', '_aggregate_select_cache']
+    q_ignored = ['join_map', 'dupe_avoidance', '_extra_select_cache', '_aggregate_select_cache',
+                 'used_aliases']
     attrs[Query] = tuple(sorted( set(q_keys) - set(q_ignored) ))
 
     for k, v in attrs.items():
@@ -454,9 +455,10 @@ class ManagerMixin(object):
             # So we just hacky strip _id from end of a key
             # TODO: make it right, _meta.get_field() should help
             filter_key = key[:-3] if key.endswith('_id') else key
-            cached_as(instance.__class__.objects \
-                .filter(**{filter_key: getattr(instance, key)}), extra='') \
-                (lambda: [instance])()
+
+            cond = {filter_key: getattr(instance, key)}
+            qs = instance.__class__.objects.inplace().filter(**cond).order_by()
+            qs._cache_results(qs._cache_key(), [instance])
 
             # Reverting stripped attributes
             instance.__dict__.update(unwanted_dict)
